@@ -1,5 +1,6 @@
 import matplotlib.pyplot as plt
 
+
 class Plotter:
     def __init__(self, grid=(1, 1, 1)):
         self.grid = grid
@@ -8,13 +9,12 @@ class Plotter:
         self.ax = 0
 
     @staticmethod
-    def __restartplot(self):
+    def __clearplot():
         plt.clf()
         plt.cla()
         plt.close()
 
     def addwire(self, geom):
-        print(geom.geom_type)
         if geom.geom_type == "Point":
             raise Exception('Cannot wire plot a Point')
         elif geom.geom_type == "LineString":
@@ -38,14 +38,16 @@ class Plotter:
             for g in geom:
                 self.addwire(g)
 
+    def clear(self):
+        self.wire = []
+
     def plot(self, restart=True):
         if restart:
-            self.__restartplot(self)
+            self.__clearplot()
         self.fig = plt.figure()
         self.ax = self.fig.add_subplot(*self.grid)
         for element in self.wire:
             self.ax.plot(element[0], element[1])
         plt.show()
         if restart:
-            self.__restartplot(self)
-
+            self.__clearplot()
